serve

Function serve 

pub async fn serve(
    addr: SocketAddr,
    vault: Vault,
    password: String,
) -> Result<(), Box<dyn Error + Send + Sync>>
Bind and serve the AgentID gRPC service on addr until the future is dropped. The password is held in memory as long as the server is alive.